Amount

Struct Amount 

pub struct Amount<C = NegativeAllowed>(i64, PhantomData<C>);
A runtime validated type for representing amounts of zatoshis

Tuple Fields

0: i64

The inner amount value.

1: PhantomData<C>

Used for Constraint type inference.

Correctness

This internal Zebra marker type is not consensus-critical. And it should be ignored during testing. (And other internal uses.)

Implementations

Source

impl Amount<NonNegative>

pub const fn new_from_zec(zec_value: i64) -> Self

Create a new non-negative Amount from a provided value in ZEC.

pub const fn new(zatoshis: i64) -> Self

Create a new non-negative Amount from a provided value in zatoshis.

pub const fn div_exact(self, rhs: i64) -> Self

Divide an Amount by a value that the amount fits into evenly such that there is no remainder.

Source

impl<C> Amount<C>

pub fn constrain<C2>(self) -> Result<Amount<C2>>
where C2: Constraint,

Convert this amount to a different Amount type if it satisfies the new constraint

pub fn zatoshis(&self) -> i64

Returns the number of zatoshis in this amount.

pub fn checked_sub<C2: Constraint>(self, rhs: Amount<C2>) -> Option<Amount>

Checked subtraction. Computes self - rhs, returning None if overflow occurred.

pub fn to_bytes(&self) -> [u8; 8]

To little endian byte array

pub fn from_bytes(bytes: [u8; 8]) -> Result<Amount<C>>
where C: Constraint,

From little endian byte array

pub fn zero() -> Amount<C>
where C: Constraint,

Create a zero Amount

pub fn is_zero(&self) -> bool

Returns true if this amount is zero.