Constraint

Trait Constraint 

pub trait Constraint {
    // Required method
    fn valid_range() -> RangeInclusive<i64>;

    // Provided method
    fn validate(value: i64) -> Result<i64, Error> { ... }
}
A trait for defining constraints on Amount

Required Methods

fn valid_range() -> RangeInclusive<i64>

Returns the range of values that are valid under this constraint

Provided Methods

fn validate(value: i64) -> Result<i64, Error>

Check if an input value is within the valid range

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors