pub struct Amount<C = NegativeAllowed>(i64, PhantomData<C>);Expand description
A runtime validated type for representing amounts of zatoshis
Tuple Fields
0: i64The inner amount value.
1: PhantomData<C>Used for Constraint type inference.
Correctness
This internal Zebra marker type is not consensus-critical. And it should be ignored during testing. (And other internal uses.)
Implementations
Sourceimpl Amount<NonNegative>
impl Amount<NonNegative>
Sourceimpl<C> Amount<C>
impl<C> Amount<C>
Sourcepub fn constrain<C2>(self) -> Result<Amount<C2>>where
C2: Constraint,
pub fn constrain<C2>(self) -> Result<Amount<C2>>where
C2: Constraint,
Convert this amount to a different Amount type if it satisfies the new constraint
Sourcepub fn checked_sub<C2: Constraint>(self, rhs: Amount<C2>) -> Option<Amount>
pub fn checked_sub<C2: Constraint>(self, rhs: Amount<C2>) -> Option<Amount>
Checked subtraction. Computes self - rhs, returning None if overflow occurred.
Sourcepub fn from_bytes(bytes: [u8; 8]) -> Result<Amount<C>>where
C: Constraint,
pub fn from_bytes(bytes: [u8; 8]) -> Result<Amount<C>>where
C: Constraint,
From little endian byte array
Sourcepub fn zero() -> Amount<C>where
C: Constraint,
pub fn zero() -> Amount<C>where
C: Constraint,
Create a zero Amount